
#ifndef _C14_fi676_
#define _C14_fi676_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F605_3221(EIF_REFERENCE);
extern void EIF_Minit676(void);
extern EIF_INTEGER_32 F706_3699(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
